<script setup lang="ts">
import SideMenu from "@/components/admin/layouts/SideMenu.vue";
import dashboard from "@/config/dashboard";
import useDashboardStore from "@/stores/dashboard";
import { Icon } from "@iconify/vue";
import { breakpointsTailwind, useBreakpoints } from "@vueuse/core";
import { ElDrawer, ElIcon } from "element-plus";
import { useI18n } from "vue-i18n";

const dashboardStore = useDashboardStore();
const { t } = useI18n();

const breakpoints = useBreakpoints(breakpointsTailwind);
const largeThanMd = breakpoints.greater("md");
</script>
<template>
  <aside>
    <template v-if="largeThanMd">
      <side-menu :collapse="!dashboardStore.expandSide" class="h-screen">
        <template #prepend>
          <li class="el-menu-item !h-[--el-menu-horizontal-height]">
            <el-icon><Icon icon="carbon:logo-vue" /></el-icon>
            <span>{{ t(dashboard.sidebar.logo.text) }}</span>
          </li>
        </template>
      </side-menu>
    </template>
    <template v-else>
      <el-drawer
        v-model="dashboardStore.expandSide"
        direction="ltr"
        :show-close="false"
        :with-header="false"
        size="--x-dashboard-sidebar-width"
      >
        <div
          class="px-[--el-menu-base-level-padding] leading-[--el-menu-item-height]"
        >
          <el-icon class="me-[5px] w-[--el-menu-icon-widthd]">
            <Icon icon="carbon:logo-vue" />
          </el-icon>
          <span>{{ t(dashboard.sidebar.logo.text) }}</span>
        </div>
        <side-menu :collapse="false" class="!border-r-0" />
      </el-drawer>
    </template>
  </aside>
</template>
